<h1 align="center">loquax</h1>
<p align="center">
</p>
<p align="center">A <i><a href="https://en.wikipedia.org/wiki/Classical_antiquity" target="_blank">Classical</a></i> Phonology framework</p>
<p align="center">
  <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
  <a href="https://codecov.io/gh/mattlianje/loquax" >
    <img src="https://codecov.io/gh/mattlianje/loquax/branch/main/graph/badge.svg?token=EBMEFP40QL"/>
  </a>
</p>

<p align="center">
Loquax, (Latin for "chatty"), is an <b><i>extensible</i></b> Python library for analyzing and manipulating phonology of endangered & extinct languages. With hobbyists and academia in mind, it provides functionality for:
</p>


- **Syllabification:** Break down words into their fundamental phonetic components.
- **Phoneme Analysis:** Understand the unique sounds and their roles within words.
- **Morphological Transformations:** Observe and manipulate the structure of words.
- **IPA Transliteration:** Convert text into the International Phonetic Alphabet for universal comprehension.
- **Scansion:** Analyze the rhythm of verse in classical poetry, and syllable weight in general.
- **Extensibility:** Build and customize your own language rules for unique or theoretical languages.

<p align="center">
... 
</p>
<p align="center">
Its a zero-dependency framework, using functional style Python 3.10+ features to revive the sounds of the past, one phoneme at a time.
</p>

